@@ -2,8 +2,10 @@
 
 from xml.etree import ElementTree as ET
 import hashlib
-from XmindToTestlink import read_xml
-#import read_xml
+try:
+    from XmindToTestlink import read_xml
+except ImportError:
+    import read_xml
 
 class DictToXml(object):
     def __init__(self):
@@ -206,7 +208,7 @@ class DictToXml(object):
             if path in self.only_reqs_id_dict:
                 if path not in suite_id:
                     suite_id[path] = pid + ".0"
-                else:
+                elif pid.split(".")[-1].isdigit():
                     old_count = int(suite_id[path].split(".")[-1])
                     now_count = int(pid.split(".")[-1])
                     if old_count < now_count:
