@@ -6,10 +6,12 @@ import os
 import sys
 import argparse
 import traceback
-from XmindToTestlink import xmind_to_dict
-from XmindToTestlink import dict_to_xml
-#import xmind_to_dict
-#import dict_to_xml
+try:
+    from XmindToTestlink import xmind_to_dict
+    from XmindToTestlink import dict_to_xml
+except ImportError:
+    import xmind_to_dict
+    import dict_to_xml
 
 def get_flist(fdir):
     flist = []
