@@ -3,8 +3,10 @@
 import json
 import copy
 from zipfile import  ZipFile
-from XmindToTestlink import preprocess
-#import preprocess
+try:
+    from XmindToTestlink import preprocess
+except ImportError:
+    import preprocess
 
 class XmindToDict(object):
     def __init__(self, xmind_type = "case"):
@@ -54,25 +56,31 @@ class XmindToDict(object):
         for attach in in_data['children']['attached']:
             find = 0
             if isinstance(attach, dict):
+                if "children" in attach and attach['children'] != {}:
+                    new_v = attach['children']['attached'][0]['title']
+                else:
+                    print("Warning: 属性：" + attach['title']  + " 未添加属性值")
+                    new_v = ""
                 ol = len(old_custom)
                 if ol >= 1:
                     for i in range(ol):
                         for k,v in old_custom[i].items():
                             if k == attach['title']:
                                 argv = old_custom[i][k].split("|")
-                                if attach['children']['attached'][0]['title'] in argv:
-                                    pass
-                                else:
-                                    old_custom[i][k] = v + "|" + attach['children']['attached'][0]['title']
+                                if new_v not in argv:
+                                    if v != "":
+                                        old_custom[i][k] = v + "|" + new_v
+                                    else:
+                                        old_custom[i][k] = new_v
                                 find = 1
                     if not find:
                         custom = {}
-                        custom[attach['title']] = attach['children']['attached'][0]['title']
+                        custom[attach['title']] = new_v
                         old_custom.append(custom)
                 else:
                     old_custom = []
                     custom = {}
-                    custom[attach['title']] = attach['children']['attached'][0]['title']
+                    custom[attach['title']] = new_v
                     old_custom.append(custom)
         return old_custom
     
