@@ -3,10 +3,12 @@ from getopt import getopt
 import copy
 import os
 import sys
-from XmindToTestlink import read_xml
-from XmindToTestlink import dict_to_xml
-#import read_xml
-#import dict_to_xml
+try:
+    from XmindToTestlink import read_xml
+    from XmindToTestlink import dict_to_xml
+except ImportError:
+    import read_xml
+    import dict_to_xml
 
 def get_dpath(in_dict, pre_path = ''):
     path_list = []
@@ -110,6 +112,8 @@ def update_common(common_path, out_dict, down_dict):
             down_req['custom_field'] = copy.deepcopy(out_req['custom_field'])
         if "detail" in out_req:
             down_req['detail'] = out_req['detail']
+        if "summary" in out_req:
+            down_req['summary'] = out_req['summary']
     return down_dict
 
 def clean_suite_case(path, in_list):
@@ -133,7 +137,7 @@ def get_common_suite(path, common_path):
 def usage():
     '''
     Usage:
-    * xmladd -d download_xml -o output_xml
+        xmladd -d download_xml -o output_xml
 
     function:
         create new xml which include out_xml and download_xml's message
